@@ -232,7 +232,6 @@ def test_add_remove(module, EXAMPLE):
 
     shared = module.Shared.from_dict(EXAMPLE['shared'])
     shared.realize()
-    print 'DEBUG', shared.dump()
 
     values = []
     group = module.Group.from_values(shared)
@@ -271,6 +270,24 @@ def test_add_remove(module, EXAMPLE):
         err_msg='group - values + values != group')
 
 
+@for_each_model()
+def test_add_repeated(module, EXAMPLE):
+    # Test add_repeated value vs n * add
+    shared = module.Shared.from_dict(EXAMPLE['shared'])
+    shared.realize()
+    for value in EXAMPLE['values']:
+        group = module.Group.from_values(shared)
+        for _ in range(DATA_COUNT):
+            group.add_value(shared, value)
+
+        group_repeated = module.Group.from_values(shared)
+        group_repeated.add_repeated_value(shared, value, count=DATA_COUNT)
+        assert_close(
+            group.dump(),
+            group_repeated.dump(),
+            err_msg='n * add_value != add_repeated_value n')
+
+
 @for_each_model()
 def test_add_merge(module, EXAMPLE):
     # Test group_add_value, group_merge
@@ -312,6 +329,32 @@ def test_group_merge(module, EXAMPLE):
         assert_close(actual.dump(), expected.dump())
 
 
+@for_each_model(lambda module: module.Value in [bool, int])
+def test_group_allows_debt(module, EXAMPLE):
+    # Test that group.add_value can safely go into data debt
+    shared = module.Shared.from_dict(EXAMPLE['shared'])
+    shared.realize()
+    values = []
+    group1 = module.Group.from_values(shared, values)
+    for _ in range(DATA_COUNT):
+        value = group1.sample_value(shared)
+        values.append(value)
+        group1.add_value(shared, value)
+
+    group2 = module.Group.from_values(shared)
+    pos_values = [(v, +1) for v in values]
+    neg_values = [(v, -1) for v in values]
+    signed_values = pos_values * 3 + neg_values * 2
+    numpy.random.shuffle(signed_values)
+    for value, sign in signed_values:
+        if sign > 0:
+            group2.add_value(shared, value)
+        else:
+            group2.remove_value(shared, value)
+
+    assert_close(group1.dump(), group2.dump())
+
+
 @for_each_model()
 def test_sample_seed(module, EXAMPLE):
     shared = module.Shared.from_dict(EXAMPLE['shared'])
@@ -510,6 +553,14 @@ def test_mixture_score(module, EXAMPLE):
         mixture.score_value(shared, value, actual)
         actual -= noise
         assert_close(actual, expected, err_msg='score_value {}'.format(value))
+        another = [
+            mixture.score_value_group(shared, i, value)
+            for i in xrange(len(groups))
+        ]
+        assert_close(
+            another,
+            expected,
+            err_msg='score_value_group {}'.format(value))
         return actual
 
     def check_score_data():
