@@ -30,9 +30,26 @@
 #include <distributions/io/schema.pb.h>
 
 namespace distributions {
-namespace protobuf {
 
-using namespace ::protobuf::distributions;
+template<class Typename> struct Protobuf;
+
+#define DECLARE_MESSAGE(Typename, decl_, special_, params_)         \
+decl_ struct Typename;                                              \
+template<special_> struct Protobuf<Typename params_>                \
+{                                                                   \
+    typedef ::protobuf::distributions::Typename t;                  \
+};
+
+DECLARE_MESSAGE(BetaBernoulli,,,)
+DECLARE_MESSAGE(DirichletDiscrete,
+    template<int max_dim>, int max_dim, <max_dim>)
+DECLARE_MESSAGE(DirichletProcessDiscrete,,,)
+DECLARE_MESSAGE(GammaPoisson,,,)
+DECLARE_MESSAGE(BetaNegativeBinomial,,,)
+DECLARE_MESSAGE(NormalInverseChiSq,,,)
+
+#undef DECLARE_MESSAGE
+
+namespace protobuf { using namespace ::protobuf::distributions; }
 
-} // namespace protobuf
 } // namespace distributions
