@@ -108,11 +108,23 @@ inline float sample_beta (
         float alpha,
         float beta)
 {
-    float x = sample_gamma(rng, alpha, 1);
-    float y = sample_gamma(rng, beta, 1);
+    float x = sample_gamma(rng, alpha);
+    float y = sample_gamma(rng, beta);
     return x / (x + y);
 }
 
+inline float sample_beta_safe (
+        rng_t & rng,
+        float alpha,
+        float beta,
+        float min_value)
+{
+    DIST_ASSERT(min_value >= 0, "bad bound: " << min_value);
+    DIST_ASSERT(alpha > 0, "bad alpha = " << alpha);
+    float p = sample_beta(rng, alpha, beta);
+    return (p + min_value) / (1.f + min_value);
+}
+
 void sample_dirichlet (
         rng_t & rng,
         size_t dim,
@@ -199,6 +211,7 @@ inline size_t sample_discrete (
         size_t dim,
         const float * probs)
 {
+    DIST_ASSERT_LT(0, dim);
     float t = sample_unif01(rng);
     for (size_t i = 0; DIST_LIKELY(i < dim - 1); ++i) {
         t -= probs[i];
@@ -216,6 +229,7 @@ inline size_t sample_from_likelihoods (
         float total_likelihood)
 {
     const size_t size = likelihoods.size();
+    DIST_ASSERT_LT(0, size);
 
     float t = total_likelihood * sample_unif01(rng);
 
