@@ -61,12 +61,23 @@ void vector_scale (
         float * __restrict__ io,
         const float scale);
 
+// io = -io
+void vector_negate (
+        const size_t size,
+        float * __restrict__ io);
+
 // io += in
 void vector_add (
         const size_t size,
         float * __restrict__ io,
         const float * __restrict__ in);
 
+// io = in - io
+void vector_negate_and_add (
+        const size_t size,
+        float * __restrict__ io,
+        const float * __restrict__ in);
+
 // io += in1 + in2
 void vector_add_add (
         const size_t size,
